@@ -1,4 +1,4 @@
-from crudlfap.models import Controller, URL
+from crudlfap.models import URL, Controller
 from crudlfap.router import Router
 from crudlfap.views import generic
 
@@ -27,7 +27,7 @@ class ControllerRouter(Router):
 
 class URLRouter(Router):
     model = URL
-    material_icon = 'link'
+    icon = 'link'
 
     views = [
         generic.DetailView,
